# Using the Mod jar #

Our recommended way of launching Minecraft is to use the launchClient script in the Minecraft folder. 
However, if you want to go through the normal Minecraft launcher instead for some reason, you can use
the jar file in this folder.

1. Install Minecraft. Visit https://minecraft.net to purchase and download.
2. Install the Minecraft Forge binaries:
   Visit http://files.minecraftforge.net/maven/net/minecraftforge/forge/index_1.8.html
   and download version 11.14.3.1543 for your platform. Select 'install client' when it asks.
   Detailed instructions: http://www.minecraftforge.net/wiki/Main_Page
3. Copy the .jar file in this folder to (on Windows) `C:\Users\${USER}\AppData\Roaming\.minecraft\mods`
   or similar for your platform.
4. Launch Minecraft through the standard Minecraft launcher (not launchClient) and log in.
   Make sure you select the forge profile in the launcher.
5. Check that the Malmo mod shows up in the Mods menu.
